# Linux
# for linux/m68k,  need to remove -fPIC
# For linux/alpha, need to compile fd_attribute.c without -O
#

CC=gcc
CCFLAG=-O2 -fPIC
LDFLAG=-O2 -s
AR=ar rs
RANLIB=touch
XINCLUDE=--I/usr/X11R6/include
SYSLIB=-L/usr/X11R6/lib -lX11 -lm
JPEG=

# where the library should be installed

LIB_TOPDIR=/usr

LIB_DIR=$(LIB_TOPDIR)/lib
LIBMODE=644

HEADER_DIR=$(LIB_TOPDIR)/include
HEADERMODE=644

BIN_DIR=/usr/local/bin
BINMODE=711

MAN5_DIR=$(LIB_TOPDIR)/man/man5
MAN1_DIR=$(LIB_TOPDIR)/man/man1
MANMODE=644

# name and header of the library
FORMLIB=libforms.a
FORMHEADER=forms.h

# make shared lib: $(MKSHLIB)
SHARED_LIB=libforms.so.0.89
SHARED_SO=libforms.so.0.89
SHARED_NAME=libforms.so

#
# this is how the shared library is made
#
MKSHLIB=ld -shared -soname $(SHARED_SO) -o $(SHARED_LIB)\
     `ls *.o|grep -v glcanvas.o` ulib/*.o ../xpm-3.4k/lib/libXpm.a $(JPEG) -lc

LN=ln -fs

#suffix for executables
EXE=

